==> haskell-wai-http2-extra-0.1.3-166-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-7fuQRupH40NLcT49YaeNJi
key:                  wai-http2-extra-0.1.3-7fuQRupH40NLcT49YaeNJi
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  61250bb4734013997c222b85ab6b6604
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-7fuQRupH40NLcT49YaeNJi
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    psqueues-0.2.8.0-3T79GxPai8dAHenwz9E9jx
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-http2-extra-0.1.3-186-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-http2-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-1cn2W17Vj234VkgAMygM0A
key:                  wai-http2-extra-0.1.3-1cn2W17Vj234VkgAMygM0A
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  b032fca89eec40d070bd6ed0b6eeea95
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-1cn2W17Vj234VkgAMygM0A
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    psqueues-0.2.8.0-3qqZkNXtUDt2qS4hnfH6YF
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
